@@ -1,9 +1,7 @@
 from typing import Optional
 from pathlib import Path
 
-from onhold.base import dumb_pipe, using_path, is_pipeline, \
-  RC_ENV_VAR, RC_OK
-
+from onhold.base import dumb_pipe, using_path, is_pipeline
 from play_sounds import play_after, DEFAULT_SOUND
 import click
 
@@ -21,9 +19,11 @@ def run(file: Path):
 
 @click.command(help="Play specified sound after job is complete.")
 @click.option('-s', '--sound_path', required=False,
-  type=click.Path(exists=True), help="Path to sound to play.")
+  type=click.Path(exists=True),
+  help="Path to sound to play.")
 @click.option('-w', '--warn', required=False,
-  is_flag=True, default=False, help="Show warnings.")
+  is_flag=True, default=False,
+  help="Show warnings.")
 def cmd(sound_path: Optional[str], warn: bool):
   with using_path(sound_path, warn, DEFAULT_SOUND, ENV_VAR) as path:
     run(path)
